==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PieChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PieChartBaseDescriptionMetadata } from "./PieChartBaseDescriptionMetadata";
import { PieChartDescription } from "./PieChartDescription";
/**
 * @hidden
 */
export let PieChartDescriptionMetadata = /*@__PURE__*/ (() => {
    class PieChartDescriptionMetadata extends Base {
        static e(a) {
            a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamPieChart");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (PieChartDescriptionMetadata.a == null) {
                PieChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PieChartDescriptionMetadata.c(PieChartDescriptionMetadata.a);
            }
            if (a.k(PieChartDescriptionMetadata.a)) {
                return;
            }
            a.ab(PieChartDescriptionMetadata.a);
        }
        static c(a) {
            PieChartBaseDescriptionMetadata.c(a);
            PieChartDescriptionMetadata.e(a);
        }
        static d(a) {
            PieChartDescriptionMetadata.b(a);
            a.ad("PieChart", () => new PieChartDescription());
            a.ac("PieChart", PieChartDescriptionMetadata.a);
        }
    }
    PieChartDescriptionMetadata.$t = markType(PieChartDescriptionMetadata, 'PieChartDescriptionMetadata');
    PieChartDescriptionMetadata.a = null;
    return PieChartDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PieChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PieChartBaseDescriptionMetadata } from "./PieChartBaseDescriptionMetadata";
import { PieChartDescription } from "./PieChartDescription";
/**
 * @hidden
 */
export let PieChartDescriptionMetadata = /*@__PURE__*/ (() => {
    class PieChartDescriptionMetadata extends Base {
        static e(a) {
            a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamPieChart");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (PieChartDescriptionMetadata.a == null) {
                PieChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PieChartDescriptionMetadata.c(PieChartDescriptionMetadata.a);
            }
            if (a.k(PieChartDescriptionMetadata.a)) {
                return;
            }
            a.ac(PieChartDescriptionMetadata.a);
        }
        static c(a) {
            PieChartBaseDescriptionMetadata.c(a);
            PieChartDescriptionMetadata.e(a);
        }
        static d(a) {
            PieChartDescriptionMetadata.b(a);
            a.ae("PieChart", () => new PieChartDescription());
            a.ad("PieChart", PieChartDescriptionMetadata.a);
        }
    }
    PieChartDescriptionMetadata.$t = markType(PieChartDescriptionMetadata, 'PieChartDescriptionMetadata');
    PieChartDescriptionMetadata.a = null;
    return PieChartDescriptionMetadata;
})();
